@@ -1,8 +1,24 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
- * Author:
- *   Chris Toshok (toshok@ximian.com)
- * Copyright (C) 2003, Ximian, Inc.
+
+/* e-book-backend-vcf.h - VCF contact backend.
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
+ * License as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ *
+ * Authors: Chris Toshok <toshok@ximian.com>
  */
 
 #ifndef __E_BOOK_BACKEND_VCF_H__
@@ -31,5 +47,5 @@ typedef struct {
 EBookBackend *e_book_backend_vcf_new      (void);
 GType       e_book_backend_vcf_get_type (void);
 
-#endif /* ! __E_BOOK_BACKEND_VCF_H__ */
+#endif /* __E_BOOK_BACKEND_VCF_H__ */
 
