@@ -84,7 +84,7 @@ G_BEGIN_DECLS
 #define EVC_X_FILE_AS          "X-EVOLUTION-FILE-AS"
 #define EVC_X_ICQ              "X-ICQ"
 #define EVC_X_JABBER           "X-JABBER"
-#define EVC_X_LIST_SHOW_ADDRESSES "X-EVOLUTION-LIST-SHOW_ADDRESSES"
+#define EVC_X_LIST_SHOW_ADDRESSES "X-EVOLUTION-LIST-SHOW-ADDRESSES"
 #define EVC_X_LIST		"X-EVOLUTION-LIST"
 #define EVC_X_MANAGER	"X-EVOLUTION-MANAGER"
 #define EVC_X_MSN		"X-MSN"
