@@ -36,73 +36,64 @@ struct _CamelMimeFilterPrivate {
 
 #define PRE_HEAD (64)
 #define BACK_HEAD (64)
-#define _PRIVATE(o) (((CamelMimeFilter *)(o))->priv)
-#define FCLASS(o) ((CamelMimeFilterClass *)(CAMEL_OBJECT_GET_CLASS(o)))
 
-static CamelObjectClass *camel_mime_filter_parent;
-
-static void complete (CamelMimeFilter *mf, const gchar *in, gsize len,
-		      gsize prespace, gchar **out, gsize *outlen,
-		      gsize *outprespace);
+G_DEFINE_ABSTRACT_TYPE (CamelMimeFilter, camel_mime_filter, CAMEL_TYPE_OBJECT)
 
 static void
-camel_mime_filter_class_init (CamelMimeFilterClass *klass)
+mime_filter_finalize (GObject *object)
 {
-	camel_mime_filter_parent = camel_type_get_global_classfuncs (camel_object_get_type ());
+	CamelMimeFilter *mime_filter;
 
-	klass->complete = complete;
+	mime_filter = CAMEL_MIME_FILTER (object);
+
+	g_free (mime_filter->outreal);
+	g_free (mime_filter->backbuf);
+	g_free (mime_filter->priv->inbuf);
+
+	/* Chain up to parent's finalize() method. */
+	G_OBJECT_CLASS (camel_mime_filter_parent_class)->finalize (object);
 }
 
 static void
-camel_mime_filter_init (CamelMimeFilter *obj)
-{
-	obj->outreal = NULL;
-	obj->outbuf = NULL;
-	obj->outsize = 0;
-
-	obj->backbuf = NULL;
-	obj->backsize = 0;
-	obj->backlen = 0;
-
-	_PRIVATE(obj) = g_malloc0(sizeof(*obj->priv));
-}
-
-static void
-camel_mime_filter_finalize(CamelObject *o)
-{
-	CamelMimeFilter *f = (CamelMimeFilter *)o;
-	struct _CamelMimeFilterPrivate *p = _PRIVATE(f);
-
-	g_free(f->outreal);
-	g_free(f->backbuf);
-	g_free(p->inbuf);
-	g_free(p);
-}
-
-CamelType
-camel_mime_filter_get_type (void)
-{
-	static CamelType camel_mime_filter_type = CAMEL_INVALID_TYPE;
-
-	if (camel_mime_filter_type == CAMEL_INVALID_TYPE) {
-		camel_mime_filter_type = camel_type_register (CAMEL_OBJECT_TYPE, "CamelMimeFilter",
-							      sizeof (CamelMimeFilter),
-							      sizeof (CamelMimeFilterClass),
-							      (CamelObjectClassInitFunc) camel_mime_filter_class_init,
-							      NULL,
-							      (CamelObjectInitFunc) camel_mime_filter_init,
-							      (CamelObjectFinalizeFunc) camel_mime_filter_finalize);
-	}
-
-	return camel_mime_filter_type;
-}
-
-static void
-complete(CamelMimeFilter *mf, const gchar *in, gsize len, gsize prespace, gchar **out, gsize *outlen, gsize *outprespace)
+mime_filter_complete (CamelMimeFilter *mime_filter,
+                      const gchar *in,
+                      gsize len,
+                      gsize prespace,
+                      gchar **out,
+                      gsize *outlen,
+                      gsize *outprespace)
 {
 	/* default - do nothing */
 }
 
+static void
+camel_mime_filter_class_init (CamelMimeFilterClass *class)
+{
+	GObjectClass *object_class;
+
+	g_type_class_add_private (class, sizeof (CamelMimeFilterPrivate));
+
+	object_class = G_OBJECT_CLASS (class);
+	object_class->finalize = mime_filter_finalize;
+
+	class->complete = mime_filter_complete;
+}
+
+static void
+camel_mime_filter_init (CamelMimeFilter *mime_filter)
+{
+	mime_filter->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		mime_filter, CAMEL_TYPE_MIME_FILTER, CamelMimeFilterPrivate);
+
+	mime_filter->outreal = NULL;
+	mime_filter->outbuf = NULL;
+	mime_filter->outsize = 0;
+
+	mime_filter->backbuf = NULL;
+	mime_filter->backsize = 0;
+	mime_filter->backlen = 0;
+}
+
 /**
  * camel_mime_filter_new:
  *
@@ -113,83 +104,83 @@ complete(CamelMimeFilter *mf, const gchar *in, gsize len, gsize prespace, gchar
 CamelMimeFilter *
 camel_mime_filter_new (void)
 {
-	CamelMimeFilter *new = CAMEL_MIME_FILTER ( camel_object_new (camel_mime_filter_get_type ()));
-	return new;
+	return g_object_new (CAMEL_TYPE_MIME_FILTER, NULL);
 }
 
 #ifdef MALLOC_CHECK
 static void
-checkmem(gpointer p)
+checkmem (gpointer p)
 {
 	if (p) {
-		gint status = mprobe(p);
+		gint status = mprobe (p);
 
 		switch (status) {
 		case MCHECK_HEAD:
 			printf("Memory underrun at %p\n", p);
-			abort();
+			abort ();
 		case MCHECK_TAIL:
 			printf("Memory overrun at %p\n", p);
-			abort();
+			abort ();
 		case MCHECK_FREE:
 			printf("Double free %p\n", p);
-			abort();
+			abort ();
 		}
 	}
 }
 #endif
 
-static void filter_run(CamelMimeFilter *f,
+static void filter_run (CamelMimeFilter *f,
 		       const gchar *in, gsize len, gsize prespace,
 		       gchar **out, gsize *outlen, gsize *outprespace,
 		       void (*filterfunc)(CamelMimeFilter *f,
 					  const gchar *in, gsize len, gsize prespace,
 					  gchar **out, gsize *outlen, gsize *outprespace))
 {
-	struct _CamelMimeFilterPrivate *p;
-
 #ifdef MALLOC_CHECK
-	checkmem(f->outreal);
-	checkmem(f->backbuf);
+	checkmem (f->outreal);
+	checkmem (f->backbuf);
 #endif
 	/*
 	  here we take a performance hit, if the input buffer doesn't
 	  have the pre-space required.  We make a buffer that does ...
 	*/
-	if (prespace < f->backlen) {
-		gint newlen = len+prespace+f->backlen;
-		p = _PRIVATE(f);
+	if (f->backlen > 0) {
+		struct _CamelMimeFilterPrivate *p;
+		gint newlen;
+
+		p = f->priv;
+
+		newlen = len + prespace + f->backlen;
 		if (p->inlen < newlen) {
 			/* NOTE: g_realloc copies data, we dont need that (slower) */
-			g_free(p->inbuf);
-			p->inbuf = g_malloc(newlen+PRE_HEAD);
+			g_free (p->inbuf);
+			p->inbuf = g_malloc (newlen+PRE_HEAD);
 			p->inlen = newlen+PRE_HEAD;
 		}
+
 		/* copy to end of structure */
-		memcpy(p->inbuf+p->inlen - len, in, len);
-		in = p->inbuf+p->inlen - len;
+		memcpy (p->inbuf + p->inlen - len, in, len);
+		in = p->inbuf + p->inlen - len;
 		prespace = p->inlen - len;
-	}
 
-#ifdef MALLOC_CHECK
-	checkmem(f->outreal);
-	checkmem(f->backbuf);
-#endif
-
-	/* preload any backed up data */
-	if (f->backlen > 0) {
-		memcpy((gchar *) in-f->backlen, f->backbuf, f->backlen);
+		/* preload any backed up data */
+		memcpy ((gchar *) in - f->backlen, f->backbuf, f->backlen);
 		in -= f->backlen;
 		len += f->backlen;
 		prespace -= f->backlen;
 		f->backlen = 0;
 	}
 
-	filterfunc(f, in, len, prespace, out, outlen, outprespace);
+#ifdef MALLOC_CHECK
+	checkmem (f->outreal);
+	checkmem (f->backbuf);
+#endif
+
+	filterfunc (f, in, len, prespace, out, outlen, outprespace);
 
 #ifdef MALLOC_CHECK
-	checkmem(f->outreal);
-	checkmem(f->backbuf);
+	checkmem (f->outreal);
+	checkmem (f->backbuf);
 #endif
 
 }
@@ -209,13 +200,24 @@ static void filter_run(CamelMimeFilter *f,
  **/
 void
 camel_mime_filter_filter (CamelMimeFilter *filter,
-			  const gchar *in, gsize len, gsize prespace,
-			  gchar **out, gsize *outlen, gsize *outprespace)
+                          const gchar *in,
+                          gsize len,
+                          gsize prespace,
+                          gchar **out,
+                          gsize *outlen,
+                          gsize *outprespace)
 {
-	if (FCLASS(filter)->filter)
-		filter_run(filter, in, len, prespace, out, outlen, outprespace, FCLASS(filter)->filter);
-	else
-		g_error("Filter function unplmenented in class");
+	CamelMimeFilterClass *class;
+
+	g_return_if_fail (CAMEL_IS_MIME_FILTER (filter));
+	g_return_if_fail (in != NULL);
+
+	class = CAMEL_MIME_FILTER_GET_CLASS (filter);
+	g_return_if_fail (class->filter != NULL);
+
+	filter_run (
+		filter, in, len, prespace, out,
+		outlen, outprespace, class->filter);
 }
 
 /**
@@ -236,11 +238,24 @@ camel_mime_filter_filter (CamelMimeFilter *filter,
  **/
 void
 camel_mime_filter_complete (CamelMimeFilter *filter,
-			    const gchar *in, gsize len, gsize prespace,
-			    gchar **out, gsize *outlen, gsize *outprespace)
+                            const gchar *in,
+                            gsize len,
+                            gsize prespace,
+                            gchar **out,
+                            gsize *outlen,
+                            gsize *outprespace)
 {
-	if (FCLASS(filter)->complete)
-		filter_run(filter, in, len, prespace, out, outlen, outprespace, FCLASS(filter)->complete);
+	CamelMimeFilterClass *class;
+
+	g_return_if_fail (CAMEL_IS_MIME_FILTER (filter));
+	g_return_if_fail (in != NULL);
+
+	class = CAMEL_MIME_FILTER_GET_CLASS (filter);
+	g_return_if_fail (class->complete != NULL);
+
+	filter_run (
+		filter, in, len, prespace, out,
+		outlen, outprespace, class->complete);
 }
 
 /**
@@ -250,11 +265,16 @@ camel_mime_filter_complete (CamelMimeFilter *filter,
  * Resets the state on @filter so that it may be used again.
  **/
 void
-camel_mime_filter_reset(CamelMimeFilter *filter)
+camel_mime_filter_reset (CamelMimeFilter *filter)
 {
-	if (FCLASS(filter)->reset) {
-		FCLASS(filter)->reset(filter);
-	}
+	CamelMimeFilterClass *class;
+
+	g_return_if_fail (CAMEL_IS_MIME_FILTER (filter));
+
+	class = CAMEL_MIME_FILTER_GET_CLASS (filter);
+
+	if (class->reset != NULL)
+		class->reset (filter);
 
 	/* could free some buffers, if they are really big? */
 	filter->backlen = 0;
@@ -272,16 +292,16 @@ camel_mime_filter_reset(CamelMimeFilter *filter)
  * Note: New calls replace old data.
  **/
 void
-camel_mime_filter_backup(CamelMimeFilter *filter, const gchar *data, gsize length)
+camel_mime_filter_backup (CamelMimeFilter *filter, const gchar *data, gsize length)
 {
 	if (filter->backsize < length) {
 		/* g_realloc copies data, unnecessary overhead */
-		g_free(filter->backbuf);
-		filter->backbuf = g_malloc(length+BACK_HEAD);
+		g_free (filter->backbuf);
+		filter->backbuf = g_malloc (length+BACK_HEAD);
 		filter->backsize = length+BACK_HEAD;
 	}
 	filter->backlen = length;
-	memcpy(filter->backbuf, data, length);
+	memcpy (filter->backbuf, data, length);
 }
 
 /**
@@ -294,15 +314,15 @@ camel_mime_filter_backup(CamelMimeFilter *filter, const gchar *data, gsize lengt
  * for filter output.
  **/
 void
-camel_mime_filter_set_size(CamelMimeFilter *filter, gsize size, gint keep)
+camel_mime_filter_set_size (CamelMimeFilter *filter, gsize size, gint keep)
 {
 	if (filter->outsize < size) {
 		gint offset = filter->outptr - filter->outreal;
 		if (keep) {
-			filter->outreal = g_realloc(filter->outreal, size + PRE_HEAD*4);
+			filter->outreal = g_realloc (filter->outreal, size + PRE_HEAD*4);
 		} else {
-			g_free(filter->outreal);
-			filter->outreal = g_malloc(size + PRE_HEAD*4);
+			g_free (filter->outreal);
+			filter->outreal = g_malloc (size + PRE_HEAD*4);
 		}
 		filter->outptr = filter->outreal + offset;
 		filter->outbuf = filter->outreal + PRE_HEAD*4;
