@@ -148,6 +148,9 @@ camel_offline_journal_write (CamelOfflineJournal *journal,
 	}
 
 	fp = fdopen (fd, "w");
+	if (!fp)
+		goto exception;
+
 	entry = journal->queue.head;
 	while (entry->next) {
 		if (CAMEL_OFFLINE_JOURNAL_GET_CLASS (journal)->entry_write (journal, entry, fp) == -1)
@@ -158,7 +161,8 @@ camel_offline_journal_write (CamelOfflineJournal *journal,
 	if (fsync (fd) == -1)
 		goto exception;
 
-	fclose (fp);
+	if (fp)
+		fclose (fp);
 
 	return 0;
 
@@ -171,7 +175,8 @@ camel_offline_journal_write (CamelOfflineJournal *journal,
 		camel_folder_get_full_name (journal->folder),
 		g_strerror (errno));
 
-	fclose (fp);
+	if (fp)
+		fclose (fp);
 
 	return -1;
 }
@@ -179,6 +184,7 @@ camel_offline_journal_write (CamelOfflineJournal *journal,
 /**
  * camel_offline_journal_replay:
  * @journal: a #CamelOfflineJournal object
+ * @cancellable: optional #GCancellable object, or %NULL
  * @error: return location for a #GError, or %NULL
  *
  * Replay all entries in the journal.
@@ -187,6 +193,7 @@ camel_offline_journal_write (CamelOfflineJournal *journal,
  **/
 gint
 camel_offline_journal_replay (CamelOfflineJournal *journal,
+                              GCancellable *cancellable,
                               GError **error)
 {
 	CamelDListNode *entry, *next;
@@ -196,7 +203,8 @@ camel_offline_journal_replay (CamelOfflineJournal *journal,
 	entry = journal->queue.head;
 	while (entry->next) {
 		next = entry->next;
-		if (CAMEL_OFFLINE_JOURNAL_GET_CLASS (journal)->entry_play (journal, entry, &local_error) == -1) {
+		if (CAMEL_OFFLINE_JOURNAL_GET_CLASS (journal)->entry_play (
+			journal, entry, cancellable, &local_error) == -1) {
 			if (failed == 0) {
 				g_propagate_error (error, local_error);
 				local_error = NULL;
