@@ -29,10 +29,6 @@
 
 #include "camel-sasl-ntlm.h"
 
-#define CAMEL_SASL_NTLM_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), CAMEL_TYPE_SASL_NTLM, CamelSaslNTLMPrivate))
-
 struct _CamelSaslNTLMPrivate {
 	gint placeholder;  /* allow for future expansion */
 };
@@ -49,10 +45,9 @@ CamelServiceAuthType camel_sasl_ntlm_authtype = {
 
 G_DEFINE_TYPE (CamelSaslNTLM, camel_sasl_ntlm, CAMEL_TYPE_SASL)
 
-#define NTLM_REQUEST "NTLMSSP\x00\x01\x00\x00\x00\x06\x82\x08\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00"
+#define NTLM_REQUEST "NTLMSSP\x00\x01\x00\x00\x00\x06\x82\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00"
 
 #define NTLM_CHALLENGE_DOMAIN_OFFSET		12
-#define NTLM_CHALLENGE_FLAGS_OFFSET		20
 #define NTLM_CHALLENGE_NONCE_OFFSET		24
 
 #define NTLM_RESPONSE_HEADER         "NTLMSSP\x00\x03\x00\x00\x00"
@@ -193,27 +188,27 @@ setup_schedule (const guchar *key_56, DES_KS ks)
 			key[i] ^= 0x01;
 	}
 
-        deskey (ks, key, 0);
+	deskey (ks, key, 0);
 }
 
 static void
 ntlm_calc_response (const guchar key[21], const guchar plaintext[8],
 		    guchar results[24])
 {
-        DES_KS ks;
+	DES_KS ks;
 
 	memcpy (results, plaintext, 8);
 	memcpy (results + 8, plaintext, 8);
 	memcpy (results + 16, plaintext, 8);
 
-        setup_schedule (key, ks);
+	setup_schedule (key, ks);
 	des (ks, results);
 
-        setup_schedule (key + 7, ks);
+	setup_schedule (key + 7, ks);
 	des (ks, results + 8);
 
-        setup_schedule (key + 14, ks);
-        des (ks, results + 16);
+	setup_schedule (key + 14, ks);
+	des (ks, results + 16);
 }
 
 /*
@@ -263,56 +258,56 @@ md4sum (const guchar *in, gint nbytes, guchar digest[16])
 		CC = C;
 		DD = D;
 
-		A = ROT (A + F(B, C, D) + X[0], 3);
-		D = ROT (D + F(A, B, C) + X[1], 7);
-		C = ROT (C + F(D, A, B) + X[2], 11);
-		B = ROT (B + F(C, D, A) + X[3], 19);
-		A = ROT (A + F(B, C, D) + X[4], 3);
-		D = ROT (D + F(A, B, C) + X[5], 7);
-		C = ROT (C + F(D, A, B) + X[6], 11);
-		B = ROT (B + F(C, D, A) + X[7], 19);
-		A = ROT (A + F(B, C, D) + X[8], 3);
-		D = ROT (D + F(A, B, C) + X[9], 7);
-		C = ROT (C + F(D, A, B) + X[10], 11);
-		B = ROT (B + F(C, D, A) + X[11], 19);
-		A = ROT (A + F(B, C, D) + X[12], 3);
-		D = ROT (D + F(A, B, C) + X[13], 7);
-		C = ROT (C + F(D, A, B) + X[14], 11);
-		B = ROT (B + F(C, D, A) + X[15], 19);
+		A = ROT (A + F (B, C, D) + X[0], 3);
+		D = ROT (D + F (A, B, C) + X[1], 7);
+		C = ROT (C + F (D, A, B) + X[2], 11);
+		B = ROT (B + F (C, D, A) + X[3], 19);
+		A = ROT (A + F (B, C, D) + X[4], 3);
+		D = ROT (D + F (A, B, C) + X[5], 7);
+		C = ROT (C + F (D, A, B) + X[6], 11);
+		B = ROT (B + F (C, D, A) + X[7], 19);
+		A = ROT (A + F (B, C, D) + X[8], 3);
+		D = ROT (D + F (A, B, C) + X[9], 7);
+		C = ROT (C + F (D, A, B) + X[10], 11);
+		B = ROT (B + F (C, D, A) + X[11], 19);
+		A = ROT (A + F (B, C, D) + X[12], 3);
+		D = ROT (D + F (A, B, C) + X[13], 7);
+		C = ROT (C + F (D, A, B) + X[14], 11);
+		B = ROT (B + F (C, D, A) + X[15], 19);
 
-		A = ROT (A + G(B, C, D) + X[0] + 0x5A827999, 3);
-		D = ROT (D + G(A, B, C) + X[4] + 0x5A827999, 5);
-		C = ROT (C + G(D, A, B) + X[8] + 0x5A827999, 9);
-		B = ROT (B + G(C, D, A) + X[12] + 0x5A827999, 13);
-		A = ROT (A + G(B, C, D) + X[1] + 0x5A827999, 3);
-		D = ROT (D + G(A, B, C) + X[5] + 0x5A827999, 5);
-		C = ROT (C + G(D, A, B) + X[9] + 0x5A827999, 9);
-		B = ROT (B + G(C, D, A) + X[13] + 0x5A827999, 13);
-		A = ROT (A + G(B, C, D) + X[2] + 0x5A827999, 3);
-		D = ROT (D + G(A, B, C) + X[6] + 0x5A827999, 5);
-		C = ROT (C + G(D, A, B) + X[10] + 0x5A827999, 9);
-		B = ROT (B + G(C, D, A) + X[14] + 0x5A827999, 13);
-		A = ROT (A + G(B, C, D) + X[3] + 0x5A827999, 3);
-		D = ROT (D + G(A, B, C) + X[7] + 0x5A827999, 5);
-		C = ROT (C + G(D, A, B) + X[11] + 0x5A827999, 9);
-		B = ROT (B + G(C, D, A) + X[15] + 0x5A827999, 13);
+		A = ROT (A + G (B, C, D) + X[0] + 0x5A827999, 3);
+		D = ROT (D + G (A, B, C) + X[4] + 0x5A827999, 5);
+		C = ROT (C + G (D, A, B) + X[8] + 0x5A827999, 9);
+		B = ROT (B + G (C, D, A) + X[12] + 0x5A827999, 13);
+		A = ROT (A + G (B, C, D) + X[1] + 0x5A827999, 3);
+		D = ROT (D + G (A, B, C) + X[5] + 0x5A827999, 5);
+		C = ROT (C + G (D, A, B) + X[9] + 0x5A827999, 9);
+		B = ROT (B + G (C, D, A) + X[13] + 0x5A827999, 13);
+		A = ROT (A + G (B, C, D) + X[2] + 0x5A827999, 3);
+		D = ROT (D + G (A, B, C) + X[6] + 0x5A827999, 5);
+		C = ROT (C + G (D, A, B) + X[10] + 0x5A827999, 9);
+		B = ROT (B + G (C, D, A) + X[14] + 0x5A827999, 13);
+		A = ROT (A + G (B, C, D) + X[3] + 0x5A827999, 3);
+		D = ROT (D + G (A, B, C) + X[7] + 0x5A827999, 5);
+		C = ROT (C + G (D, A, B) + X[11] + 0x5A827999, 9);
+		B = ROT (B + G (C, D, A) + X[15] + 0x5A827999, 13);
 
-		A = ROT (A + H(B, C, D) + X[0] + 0x6ED9EBA1, 3);
-		D = ROT (D + H(A, B, C) + X[8] + 0x6ED9EBA1, 9);
-		C = ROT (C + H(D, A, B) + X[4] + 0x6ED9EBA1, 11);
-		B = ROT (B + H(C, D, A) + X[12] + 0x6ED9EBA1, 15);
-		A = ROT (A + H(B, C, D) + X[2] + 0x6ED9EBA1, 3);
-		D = ROT (D + H(A, B, C) + X[10] + 0x6ED9EBA1, 9);
-		C = ROT (C + H(D, A, B) + X[6] + 0x6ED9EBA1, 11);
-		B = ROT (B + H(C, D, A) + X[14] + 0x6ED9EBA1, 15);
-		A = ROT (A + H(B, C, D) + X[1] + 0x6ED9EBA1, 3);
-		D = ROT (D + H(A, B, C) + X[9] + 0x6ED9EBA1, 9);
-		C = ROT (C + H(D, A, B) + X[5] + 0x6ED9EBA1, 11);
-		B = ROT (B + H(C, D, A) + X[13] + 0x6ED9EBA1, 15);
-		A = ROT (A + H(B, C, D) + X[3] + 0x6ED9EBA1, 3);
-		D = ROT (D + H(A, B, C) + X[11] + 0x6ED9EBA1, 9);
-		C = ROT (C + H(D, A, B) + X[7] + 0x6ED9EBA1, 11);
-		B = ROT (B + H(C, D, A) + X[15] + 0x6ED9EBA1, 15);
+		A = ROT (A + H (B, C, D) + X[0] + 0x6ED9EBA1, 3);
+		D = ROT (D + H (A, B, C) + X[8] + 0x6ED9EBA1, 9);
+		C = ROT (C + H (D, A, B) + X[4] + 0x6ED9EBA1, 11);
+		B = ROT (B + H (C, D, A) + X[12] + 0x6ED9EBA1, 15);
+		A = ROT (A + H (B, C, D) + X[2] + 0x6ED9EBA1, 3);
+		D = ROT (D + H (A, B, C) + X[10] + 0x6ED9EBA1, 9);
+		C = ROT (C + H (D, A, B) + X[6] + 0x6ED9EBA1, 11);
+		B = ROT (B + H (C, D, A) + X[14] + 0x6ED9EBA1, 15);
+		A = ROT (A + H (B, C, D) + X[1] + 0x6ED9EBA1, 3);
+		D = ROT (D + H (A, B, C) + X[9] + 0x6ED9EBA1, 9);
+		C = ROT (C + H (D, A, B) + X[5] + 0x6ED9EBA1, 11);
+		B = ROT (B + H (C, D, A) + X[13] + 0x6ED9EBA1, 15);
+		A = ROT (A + H (B, C, D) + X[3] + 0x6ED9EBA1, 3);
+		D = ROT (D + H (A, B, C) + X[11] + 0x6ED9EBA1, 9);
+		C = ROT (C + H (D, A, B) + X[7] + 0x6ED9EBA1, 11);
+		B = ROT (B + H (C, D, A) + X[15] + 0x6ED9EBA1, 15);
 
 		A += AA;
 		B += BB;
@@ -529,22 +524,22 @@ des (guint32 ks[16][2], guchar block[8])
 	left = (left << 1) | (left >> 31);
 
 	/* Now do the 16 rounds */
-	F(left,right,ks[0]);
-	F(right,left,ks[1]);
-	F(left,right,ks[2]);
-	F(right,left,ks[3]);
-	F(left,right,ks[4]);
-	F(right,left,ks[5]);
-	F(left,right,ks[6]);
-	F(right,left,ks[7]);
-	F(left,right,ks[8]);
-	F(right,left,ks[9]);
-	F(left,right,ks[10]);
-	F(right,left,ks[11]);
-	F(left,right,ks[12]);
-	F(right,left,ks[13]);
-	F(left,right,ks[14]);
-	F(right,left,ks[15]);
+	F (left,right,ks[0]);
+	F (right,left,ks[1]);
+	F (left,right,ks[2]);
+	F (right,left,ks[3]);
+	F (left,right,ks[4]);
+	F (right,left,ks[5]);
+	F (left,right,ks[6]);
+	F (right,left,ks[7]);
+	F (left,right,ks[8]);
+	F (right,left,ks[9]);
+	F (left,right,ks[10]);
+	F (right,left,ks[11]);
+	F (left,right,ks[12]);
+	F (right,left,ks[13]);
+	F (left,right,ks[14]);
+	F (right,left,ks[15]);
 
 	/* Inverse permutation, also from Hoey via Outerbridge and Schneier */
 	right = (right << 31) | (right >> 1);
@@ -635,7 +630,7 @@ deskey (DES_KS k, guchar *key, gint decrypt)
 			? 1 : 0;	/* and store 1-bit result */
 	}
 	for (i=0; i<16; i++) {		/* key chunk for each iteration */
-		memset(ks,0,sizeof(ks));	/* Clear key schedule */
+		memset (ks,0,sizeof (ks));	/* Clear key schedule */
 		for (j=0; j<56; j++)	/* rotate pc1 the right amount */
 			pcr[j] = pc1m[(l=j+totrot[decrypt? 15-i : i])<(j<28? 28 : 56) ? l: l-28];
 			/* rotate left and right halves independently */
@@ -660,15 +655,15 @@ deskey (DES_KS k, guchar *key, gint decrypt)
 }
 
 static GByteArray *
-sasl_ntlm_challenge (CamelSasl *sasl,
-                     GByteArray *token,
-                     GError **error)
+sasl_ntlm_challenge_sync (CamelSasl *sasl,
+                          GByteArray *token,
+                          GCancellable *cancellable,
+                          GError **error)
 {
 	CamelService *service;
 	GByteArray *ret;
-	gchar *user;
 	guchar nonce[8], hash[21], lm_resp[24], nt_resp[24];
-	GString *domain = NULL;
+	GString *domain;
 
 	service = camel_sasl_get_service (sasl);
 
@@ -677,59 +672,13 @@ sasl_ntlm_challenge (CamelSasl *sasl,
 	if (!token || token->len < NTLM_CHALLENGE_NONCE_OFFSET + 8)
 		goto fail;
 
-	/* 0x00080000: Negotiate NTLM2 Key */
-	if (token->data[NTLM_CHALLENGE_FLAGS_OFFSET + 2] & 8) {
-		/* NTLM2 session response */
-		struct {
-			guint32 srv[2];
-			guint32 clnt[2];
-		} sess_nonce;
-		GChecksum *md5;
-		guint8 digest[16];
-		gsize digest_len = sizeof(digest);
+	memcpy (nonce, token->data + NTLM_CHALLENGE_NONCE_OFFSET, 8);
+	ntlm_lanmanager_hash (service->url->passwd, (gchar *) hash);
+	ntlm_calc_response (hash, nonce, lm_resp);
+	ntlm_nt_hash (service->url->passwd, (gchar *) hash);
+	ntlm_calc_response (hash, nonce, nt_resp);
 
-		sess_nonce.clnt[0] = g_random_int();
-		sess_nonce.clnt[1] = g_random_int();
-
-		/* LM response is 8-byte client nonce, NUL-padded to 24 */
-		memcpy(lm_resp, sess_nonce.clnt, 8);
-		memset(lm_resp + 8, 0, 16);
-
-		/* Session nonce is client nonce + server nonce */
-		memcpy (sess_nonce.srv,
-			token->data + NTLM_CHALLENGE_NONCE_OFFSET, 8);
-
-		/* Take MD5 of session nonce */
-		md5 = g_checksum_new (G_CHECKSUM_MD5);
-		g_checksum_update (md5, (void *)&sess_nonce, 16);
-		g_checksum_get_digest (md5, (void *)&digest, &digest_len);
-		g_checksum_get_digest (md5, digest, &digest_len);
-
-		g_checksum_free (md5);
-		ntlm_nt_hash (service->url->passwd, (gchar *) hash);
-
-		ntlm_calc_response (hash, digest, nt_resp);
-	} else {
-		/* NTLM1 */
-		memcpy (nonce, token->data + NTLM_CHALLENGE_NONCE_OFFSET, 8);
-		ntlm_lanmanager_hash (service->url->passwd, (gchar *) hash);
-		ntlm_calc_response (hash, nonce, lm_resp);
-		ntlm_nt_hash (service->url->passwd, (gchar *) hash);
-		ntlm_calc_response (hash, nonce, nt_resp);
-	}
-
-	/* If a domain is supplied as part of the username, use it */
-	user = strchr (service->url->user, '\\');
-	if (user) {
-		domain = g_string_new_len (service->url->user,
-					   user - service->url->user);
-		user++;
-	} else
-		user = service->url->user;
-
-	/* Otherwise, fall back to the domain of the server, if possible */
-	if (domain == NULL)
-		domain = ntlm_get_string (token, NTLM_CHALLENGE_DOMAIN_OFFSET);
+	domain = ntlm_get_string (token, NTLM_CHALLENGE_DOMAIN_OFFSET);
 	if (domain == NULL)
 		goto fail;
 
@@ -740,14 +689,12 @@ sasl_ntlm_challenge (CamelSasl *sasl,
 		sizeof (NTLM_RESPONSE_HEADER) - 1);
 	memcpy (ret->data + NTLM_RESPONSE_FLAGS_OFFSET,
 		NTLM_RESPONSE_FLAGS, sizeof (NTLM_RESPONSE_FLAGS) - 1);
-	/* Mask in the NTLM2SESSION flag */
-	ret->data[NTLM_RESPONSE_FLAGS_OFFSET + 2] |=
-		token->data[NTLM_CHALLENGE_FLAGS_OFFSET + 2] & 8;
 
 	ntlm_set_string (ret, NTLM_RESPONSE_DOMAIN_OFFSET,
 			 domain->str, domain->len);
 	ntlm_set_string (ret, NTLM_RESPONSE_USER_OFFSET,
-			 user, strlen (user));
+			 service->url->user,
+			 strlen (service->url->user));
 	ntlm_set_string (ret, NTLM_RESPONSE_HOST_OFFSET,
 			 "UNKNOWN", sizeof ("UNKNOWN") - 1);
 	ntlm_set_string (ret, NTLM_RESPONSE_LM_RESP_OFFSET,
@@ -779,11 +726,12 @@ camel_sasl_ntlm_class_init (CamelSaslNTLMClass *class)
 	g_type_class_add_private (class, sizeof (CamelSaslNTLMPrivate));
 
 	sasl_class = CAMEL_SASL_CLASS (class);
-	sasl_class->challenge = sasl_ntlm_challenge;
+	sasl_class->challenge_sync = sasl_ntlm_challenge_sync;
 }
 
 static void
 camel_sasl_ntlm_init (CamelSaslNTLM *sasl)
 {
-	sasl->priv = CAMEL_SASL_NTLM_GET_PRIVATE (sasl);
+	sasl->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		sasl, CAMEL_TYPE_SASL_NTLM, CamelSaslNTLMPrivate);
 }
