@@ -39,22 +39,23 @@
 #include "camel-stream-fs.h"
 #include "camel-win32.h"
 
-#define CAMEL_STREAM_FS_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), CAMEL_TYPE_STREAM_FS, CamelStreamFsPrivate))
-
 struct _CamelStreamFsPrivate {
 	gint fd;	/* file descriptor on the underlying file */
 };
 
-G_DEFINE_TYPE (CamelStreamFs, camel_stream_fs, CAMEL_TYPE_SEEKABLE_STREAM)
+/* Forward Declarations */
+static void camel_stream_fs_seekable_init (GSeekableIface *interface);
+
+G_DEFINE_TYPE_WITH_CODE (
+	CamelStreamFs, camel_stream_fs, CAMEL_TYPE_STREAM,
+	G_IMPLEMENT_INTERFACE (G_TYPE_SEEKABLE, camel_stream_fs_seekable_init))
 
 static void
 stream_fs_finalize (GObject *object)
 {
 	CamelStreamFsPrivate *priv;
 
-	priv = CAMEL_STREAM_FS_GET_PRIVATE (object);
+	priv = CAMEL_STREAM_FS (object)->priv;
 
 	if (priv->fd != -1)
 		close (priv->fd);
@@ -71,20 +72,13 @@ stream_fs_read (CamelStream *stream,
                 GError **error)
 {
 	CamelStreamFsPrivate *priv;
-	CamelSeekableStream *seekable;
 	gssize nread;
 
-	priv = CAMEL_STREAM_FS_GET_PRIVATE (stream);
-	seekable = CAMEL_SEEKABLE_STREAM (stream);
-
-	if (seekable->bound_end != CAMEL_STREAM_UNBOUND)
-		n = MIN (seekable->bound_end - seekable->position, n);
+	priv = CAMEL_STREAM_FS (stream)->priv;
 
 	nread = camel_read (priv->fd, buffer, n, cancellable, error);
 
-	if (nread > 0)
-		seekable->position += nread;
-	else if (nread == 0)
+	if (nread == 0)
 		stream->eos = TRUE;
 
 	return nread;
@@ -98,21 +92,10 @@ stream_fs_write (CamelStream *stream,
                  GError **error)
 {
 	CamelStreamFsPrivate *priv;
-	CamelSeekableStream *seekable;
-	gssize nwritten;
 
-	priv = CAMEL_STREAM_FS_GET_PRIVATE (stream);
-	seekable = CAMEL_SEEKABLE_STREAM (stream);
+	priv = CAMEL_STREAM_FS (stream)->priv;
 
-	if (seekable->bound_end != CAMEL_STREAM_UNBOUND)
-		n = MIN (seekable->bound_end - seekable->position, n);
-
-	nwritten = camel_write (priv->fd, buffer, n, cancellable, error);
-
-	if (nwritten > 0)
-		seekable->position += nwritten;
-
-	return nwritten;
+	return camel_write (priv->fd, buffer, n, cancellable, error);
 }
 
 static gint
@@ -122,7 +105,10 @@ stream_fs_flush (CamelStream *stream,
 {
 	CamelStreamFsPrivate *priv;
 
-	priv = CAMEL_STREAM_FS_GET_PRIVATE (stream);
+	priv = CAMEL_STREAM_FS (stream)->priv;
+
+	if (g_cancellable_set_error_if_cancelled (cancellable, error))
+		return -1;
 
 	if (fsync (priv->fd) == -1) {
 		g_set_error (
@@ -142,7 +128,10 @@ stream_fs_close (CamelStream *stream,
 {
 	CamelStreamFsPrivate *priv;
 
-	priv = CAMEL_STREAM_FS_GET_PRIVATE (stream);
+	priv = CAMEL_STREAM_FS (stream)->priv;
+
+	if (g_cancellable_set_error_if_cancelled (cancellable, error))
+		return -1;
 
 	if (close (priv->fd) == -1) {
 		g_set_error (
@@ -158,60 +147,84 @@ stream_fs_close (CamelStream *stream,
 }
 
 static goffset
-stream_fs_seek (CamelSeekableStream *stream,
+stream_fs_tell (GSeekable *seekable)
+{
+	CamelStreamFsPrivate *priv;
+
+	priv = CAMEL_STREAM_FS (seekable)->priv;
+
+	return (goffset) lseek (priv->fd, 0, SEEK_CUR);
+}
+
+static gboolean
+stream_fs_can_seek (GSeekable *seekable)
+{
+	return TRUE;
+}
+
+static gboolean
+stream_fs_seek (GSeekable *seekable,
                 goffset offset,
-                CamelStreamSeekPolicy policy,
+                GSeekType type,
+                GCancellable *cancellable,
                 GError **error)
 {
 	CamelStreamFsPrivate *priv;
 	goffset real = 0;
 
-	priv = CAMEL_STREAM_FS_GET_PRIVATE (stream);
+	priv = CAMEL_STREAM_FS (seekable)->priv;
 
-	switch (policy) {
-	case CAMEL_STREAM_SET:
+	switch (type) {
+	case G_SEEK_SET:
 		real = offset;
 		break;
-	case CAMEL_STREAM_CUR:
-		real = stream->position + offset;
+	case G_SEEK_CUR:
+		real = g_seekable_tell (seekable) + offset;
 		break;
-	case CAMEL_STREAM_END:
-		if (stream->bound_end == CAMEL_STREAM_UNBOUND) {
-			real = lseek (priv->fd, offset, SEEK_END);
-			if (real != -1) {
-				if (real<stream->bound_start)
-					real = stream->bound_start;
-				stream->position = real;
-			} else
-				g_set_error (
-					error, G_IO_ERROR,
-					g_io_error_from_errno (errno),
-					"%s", g_strerror (errno));
-			return real;
+	case G_SEEK_END:
+		real = lseek (priv->fd, offset, SEEK_END);
+		if (real == -1) {
+			g_set_error (
+				error, G_IO_ERROR,
+				g_io_error_from_errno (errno),
+				"%s", g_strerror (errno));
+			return FALSE;
 		}
-		real = stream->bound_end + offset;
-		break;
+		return TRUE;
 	}
 
-	if (stream->bound_end != CAMEL_STREAM_UNBOUND)
-		real = MIN (real, stream->bound_end);
-	real = MAX (real, stream->bound_start);
-
 	real = lseek (priv->fd, real, SEEK_SET);
 	if (real == -1) {
 		g_set_error (
 			error, G_IO_ERROR,
 			g_io_error_from_errno (errno),
 			"%s", g_strerror (errno));
-		return -1;
+		return FALSE;
 	}
 
-	if (real != stream->position && ((CamelStream *)stream)->eos)
-		((CamelStream *)stream)->eos = FALSE;
+	CAMEL_STREAM (seekable)->eos = FALSE;
 
-	stream->position = real;
+	return TRUE;
+}
 
-	return real;
+static gboolean
+stream_fs_can_truncate (GSeekable *seekable)
+{
+	return FALSE;
+}
+
+static gboolean
+stream_fs_truncate_fn (GSeekable *seekable,
+                       goffset offset,
+                       GCancellable *cancellable,
+                       GError **error)
+{
+	/* XXX Don't bother translating this.  Camel never calls it. */
+	g_set_error (
+		error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+		"Truncation is not supported");
+
+	return FALSE;
 }
 
 static void
@@ -219,7 +232,6 @@ camel_stream_fs_class_init (CamelStreamFsClass *class)
 {
 	GObjectClass *object_class;
 	CamelStreamClass *stream_class;
-	CamelSeekableStreamClass *seekable_stream_class;
 
 	g_type_class_add_private (class, sizeof (CamelStreamFsPrivate));
 
@@ -231,18 +243,24 @@ camel_stream_fs_class_init (CamelStreamFsClass *class)
 	stream_class->write = stream_fs_write;
 	stream_class->flush = stream_fs_flush;
 	stream_class->close = stream_fs_close;
+}
 
-	seekable_stream_class = CAMEL_SEEKABLE_STREAM_CLASS (class);
-	seekable_stream_class->seek = stream_fs_seek;
+static void
+camel_stream_fs_seekable_init (GSeekableIface *interface)
+{
+	interface->tell = stream_fs_tell;
+	interface->can_seek = stream_fs_can_seek;
+	interface->seek = stream_fs_seek;
+	interface->can_truncate = stream_fs_can_truncate;
+	interface->truncate_fn = stream_fs_truncate_fn;
 }
 
 static void
 camel_stream_fs_init (CamelStreamFs *stream)
 {
-	stream->priv = CAMEL_STREAM_FS_GET_PRIVATE (stream);
+	stream->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		stream, CAMEL_TYPE_STREAM_FS, CamelStreamFsPrivate);
 	stream->priv->fd = -1;
-
-	CAMEL_SEEKABLE_STREAM (stream)->bound_end = CAMEL_STREAM_UNBOUND;
 }
 
 /**
@@ -260,45 +278,14 @@ camel_stream_fs_new_with_fd (gint fd)
 {
 	CamelStreamFsPrivate *priv;
 	CamelStream *stream;
-	goffset offset;
 
 	if (fd == -1)
 		return NULL;
 
 	stream = g_object_new (CAMEL_TYPE_STREAM_FS, NULL);
-	priv = CAMEL_STREAM_FS_GET_PRIVATE (stream);
+	priv = CAMEL_STREAM_FS (stream)->priv;
 
 	priv->fd = fd;
-	offset = lseek (fd, 0, SEEK_CUR);
-	if (offset == -1)
-		offset = 0;
-	CAMEL_SEEKABLE_STREAM (stream)->position = offset;
-
-	return stream;
-}
-
-/**
- * camel_stream_fs_new_with_fd_and_bounds:
- * @fd: a file descriptor
- * @start: the first valid position in the file
- * @end: the first invalid position in the file, or #CAMEL_STREAM_UNBOUND
- *
- * Gets a stream associated with the given file descriptor and bounds.
- * When the stream is destroyed, the file descriptor will be closed.
- *
- * Returns: the bound stream
- **/
-CamelStream *
-camel_stream_fs_new_with_fd_and_bounds (gint fd,
-                                        goffset start,
-                                        goffset end,
-                                        GError **error)
-{
-	CamelStream *stream;
-
-	stream = camel_stream_fs_new_with_fd (fd);
-	camel_seekable_stream_set_bounds (
-		CAMEL_SEEKABLE_STREAM (stream), start, end, error);
 
 	return stream;
 }
@@ -335,46 +322,6 @@ camel_stream_fs_new_with_name (const gchar *name,
 	return camel_stream_fs_new_with_fd (fd);
 }
 
-/**
- * camel_stream_fs_new_with_name_and_bounds:
- * @name: a local filename
- * @flags: flags as in open(2)
- * @mode: a file mode
- * @start: the first valid position in the file
- * @end: the first invalid position in the file, or #CAMEL_STREAM_UNBOUND
- * @error: return location for a #GError, or %NULL
- *
- * Creates a new CamelStream corresponding to the given arguments.
- *
- * Returns: the stream, or %NULL on error.
- **/
-CamelStream *
-camel_stream_fs_new_with_name_and_bounds (const gchar *name,
-                                          gint flags,
-                                          mode_t mode,
-                                          goffset start,
-                                          goffset end,
-                                          GError **error)
-{
-	CamelStream *stream;
-	gint retval;
-
-	stream = camel_stream_fs_new_with_name (name, flags, mode, error);
-	if (stream == NULL)
-		return NULL;
-
-	retval = camel_seekable_stream_set_bounds (
-		CAMEL_SEEKABLE_STREAM (stream),
-		start, end, error);
-
-	if (retval == -1) {
-		g_object_unref (stream);
-		stream = NULL;
-	}
-
-	return stream;
-}
-
 /**
  * camel_stream_fs_get_fd:
  * @stream: a #CamelStream
