@@ -34,19 +34,21 @@
 
 #include "camel-stream-mem.h"
 
-#define CAMEL_STREAM_MEM_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), CAMEL_TYPE_STREAM_MEM, CamelStreamMemPrivate))
-
 struct _CamelStreamMemPrivate {
 	guint owner  : 1;	/* do we own the buffer? */
 	guint secure : 1;	/* do we clear the buffer on finalize?
 				   (only if we own it) */
 
 	GByteArray *buffer;
+	goffset position;
 };
 
-G_DEFINE_TYPE (CamelStreamMem, camel_stream_mem, CAMEL_TYPE_SEEKABLE_STREAM)
+/* Forward Declarations */
+static void camel_stream_mem_seekable_init (GSeekableIface *interface);
+
+G_DEFINE_TYPE_WITH_CODE (
+	CamelStreamMem, camel_stream_mem, CAMEL_TYPE_STREAM,
+	G_IMPLEMENT_INTERFACE (G_TYPE_SEEKABLE, camel_stream_mem_seekable_init))
 
 /* could probably be a util method */
 static void
@@ -63,7 +65,7 @@ clear_mem (gpointer p, gsize len)
 		len -= 4;
 	}
 
-	memset(s, 0xbf, len);
+	memset (s, 0xbf, len);
 }
 
 static void
@@ -71,7 +73,7 @@ stream_mem_finalize (GObject *object)
 {
 	CamelStreamMemPrivate *priv;
 
-	priv = CAMEL_STREAM_MEM_GET_PRIVATE (object);
+	priv = CAMEL_STREAM_MEM (object)->priv;
 
 	if (priv->buffer && priv->owner) {
 		/* TODO: we need our own bytearray type since we don't know
@@ -89,21 +91,18 @@ static gssize
 stream_mem_read (CamelStream *stream,
                  gchar *buffer,
                  gsize n,
+                 GCancellable *cancellable,
                  GError **error)
 {
 	CamelStreamMemPrivate *priv;
-	CamelSeekableStream *seekable = CAMEL_SEEKABLE_STREAM (stream);
 	gssize nread;
 
-	priv = CAMEL_STREAM_MEM_GET_PRIVATE (stream);
+	priv = CAMEL_STREAM_MEM (stream)->priv;
 
-	if (seekable->bound_end != CAMEL_STREAM_UNBOUND)
-		n = MIN(seekable->bound_end - seekable->position, n);
-
-	nread = MIN (n, priv->buffer->len - seekable->position);
+	nread = MIN (n, priv->buffer->len - priv->position);
 	if (nread > 0) {
-		memcpy (buffer, priv->buffer->data + seekable->position, nread);
-		seekable->position += nread;
+		memcpy (buffer, priv->buffer->data + priv->position, nread);
+		priv->position += nread;
 	} else
 		nread = 0;
 
@@ -114,25 +113,22 @@ static gssize
 stream_mem_write (CamelStream *stream,
                   const gchar *buffer,
                   gsize n,
+                  GCancellable *cancellable,
                   GError **error)
 {
 	CamelStreamMemPrivate *priv;
-	CamelSeekableStream *seekable = CAMEL_SEEKABLE_STREAM (stream);
 	gssize nwrite = n;
 
-	priv = CAMEL_STREAM_MEM_GET_PRIVATE (stream);
-
-	if (seekable->bound_end != CAMEL_STREAM_UNBOUND)
-		nwrite = MIN(seekable->bound_end - seekable->position, n);
+	priv = CAMEL_STREAM_MEM (stream)->priv;
 
 	/* FIXME: we shouldn't use g_byte_arrays or g_malloc perhaps? */
-	if (seekable->position == priv->buffer->len) {
+	if (priv->position == priv->buffer->len) {
 		g_byte_array_append (priv->buffer, (const guint8 *)buffer, nwrite);
 	} else {
 		g_byte_array_set_size (priv->buffer, nwrite + priv->buffer->len);
-		memcpy (priv->buffer->data + seekable->position, buffer, nwrite);
+		memcpy (priv->buffer->data + priv->position, buffer, nwrite);
 	}
-	seekable->position += nwrite;
+	priv->position += nwrite;
 
 	return nwrite;
 }
@@ -141,32 +137,48 @@ static gboolean
 stream_mem_eos (CamelStream *stream)
 {
 	CamelStreamMemPrivate *priv;
-	CamelSeekableStream *seekable_stream = CAMEL_SEEKABLE_STREAM (stream);
 
-	priv = CAMEL_STREAM_MEM_GET_PRIVATE (stream);
+	priv = CAMEL_STREAM_MEM (stream)->priv;
 
-	return priv->buffer->len <= seekable_stream->position;
+	return priv->buffer->len <= priv->position;
 }
 
-static off_t
-stream_mem_seek (CamelSeekableStream *stream,
-                 off_t offset,
-                 CamelStreamSeekPolicy policy,
+static goffset
+stream_mem_tell (GSeekable *seekable)
+{
+	CamelStreamMemPrivate *priv;
+
+	priv = CAMEL_STREAM_MEM (seekable)->priv;
+
+	return priv->position;
+}
+
+static gboolean
+stream_mem_can_seek (GSeekable *seekable)
+{
+	return TRUE;
+}
+
+static gboolean
+stream_mem_seek (GSeekable *seekable,
+                 goffset offset,
+                 GSeekType type,
+                 GCancellable *cancellable,
                  GError **error)
 {
 	CamelStreamMemPrivate *priv;
-	off_t position;
+	goffset position;
 
-	priv = CAMEL_STREAM_MEM_GET_PRIVATE (stream);
+	priv = CAMEL_STREAM_MEM (seekable)->priv;
 
-	switch  (policy) {
-	case CAMEL_STREAM_SET:
+	switch (type) {
+	case G_SEEK_SET:
 		position = offset;
 		break;
-	case CAMEL_STREAM_CUR:
-		position = stream->position + offset;
+	case G_SEEK_CUR:
+		position = priv->position + offset;
 		break;
-	case CAMEL_STREAM_END:
+	case G_SEEK_END:
 		position = (priv->buffer)->len + offset;
 		break;
 	default:
@@ -174,12 +186,7 @@ stream_mem_seek (CamelSeekableStream *stream,
 		break;
 	}
 
-	if (stream->bound_end != CAMEL_STREAM_UNBOUND)
-		position = MIN (position, stream->bound_end);
-	if (stream->bound_start != CAMEL_STREAM_UNBOUND)
-		position = MAX (position, 0);
-	else
-		position = MAX (position, stream->bound_start);
+	position = MAX (position, 0);
 
 	if (position > priv->buffer->len) {
 		gint oldlen = priv->buffer->len;
@@ -188,9 +195,29 @@ stream_mem_seek (CamelSeekableStream *stream,
 			position - oldlen);
 	}
 
-	stream->position = position;
+	priv->position = position;
 
-	return position;
+	return TRUE;
+}
+
+static gboolean
+stream_mem_can_truncate (GSeekable *seekable)
+{
+	return FALSE;
+}
+
+static gboolean
+stream_mem_truncate_fn (GSeekable *seekable,
+                        goffset offset,
+                        GCancellable *cancellable,
+                        GError **error)
+{
+	/* XXX Don't bother translating this.  Camel never calls it. */
+	g_set_error (
+		error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+		"Truncation is not supported");
+
+	return FALSE;
 }
 
 static void
@@ -198,7 +225,6 @@ camel_stream_mem_class_init (CamelStreamMemClass *class)
 {
 	GObjectClass *object_class;
 	CamelStreamClass *stream_class;
-	CamelSeekableStreamClass *seekable_stream_class;
 
 	g_type_class_add_private (class, sizeof (CamelStreamMemPrivate));
 
@@ -209,15 +235,23 @@ camel_stream_mem_class_init (CamelStreamMemClass *class)
 	stream_class->read = stream_mem_read;
 	stream_class->write = stream_mem_write;
 	stream_class->eos = stream_mem_eos;
+}
 
-	seekable_stream_class = CAMEL_SEEKABLE_STREAM_CLASS (class);
-	seekable_stream_class->seek = stream_mem_seek;
+static void
+camel_stream_mem_seekable_init (GSeekableIface *interface)
+{
+	interface->tell = stream_mem_tell;
+	interface->can_seek = stream_mem_can_seek;
+	interface->seek = stream_mem_seek;
+	interface->can_truncate = stream_mem_can_truncate;
+	interface->truncate_fn = stream_mem_truncate_fn;
 }
 
 static void
 camel_stream_mem_init (CamelStreamMem *stream)
 {
-	stream->priv = CAMEL_STREAM_MEM_GET_PRIVATE (stream);
+	stream->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		stream, CAMEL_TYPE_STREAM_MEM, CamelStreamMemPrivate);
 }
 
 /**
@@ -280,7 +314,7 @@ camel_stream_mem_new_with_byte_array (GByteArray *buffer)
 	g_return_val_if_fail (buffer != NULL, NULL);
 
 	stream = g_object_new (CAMEL_TYPE_STREAM_MEM, NULL);
-	priv = CAMEL_STREAM_MEM_GET_PRIVATE (stream);
+	priv = CAMEL_STREAM_MEM (stream)->priv;
 
 	priv->buffer = buffer;
 	priv->owner = TRUE;
@@ -297,7 +331,7 @@ camel_stream_mem_new_with_byte_array (GByteArray *buffer)
  * This only applies to buffers owned by the stream.
  **/
 void
-camel_stream_mem_set_secure(CamelStreamMem *mem)
+camel_stream_mem_set_secure (CamelStreamMem *mem)
 {
 	g_return_if_fail (CAMEL_IS_STREAM_MEM (mem));
 
@@ -310,7 +344,7 @@ camel_stream_mem_set_secure(CamelStreamMem *mem)
  * camel_stream_mem_get_byte_array:
  * @mem: a #CamelStreamMem
  *
- * Since: 3.0
+ * Since: 2.32
  **/
 GByteArray *
 camel_stream_mem_get_byte_array (CamelStreamMem *mem)
@@ -370,7 +404,7 @@ camel_stream_mem_set_buffer (CamelStreamMem *mem,
 	g_return_if_fail (buffer != NULL);
 
 	ba = g_byte_array_new ();
-	g_byte_array_append(ba, (const guint8 *)buffer, len);
-	camel_stream_mem_set_byte_array(mem, ba);
+	g_byte_array_append (ba, (const guint8 *)buffer, len);
+	camel_stream_mem_set_byte_array (mem, ba);
 	mem->priv->owner = TRUE;
 }
