@@ -1,5 +1,5 @@
 #ifndef CAMEL_IMAP_PRIVATE_H
-#define CAMEL_IMAP_PRIVATE_H 1
+#define CAMEL_IMAP_PRIVATE_H
 
 /* need a way to configure and save this data, if this header is to
    be installed.  For now, dont install it */
@@ -15,17 +15,19 @@ struct _CamelImapFolderPrivate {
 	GStaticMutex search_lock;	/* for locking the search object */
 	GStaticRecMutex cache_lock;	/* for locking the cache object */
 #endif
+	GHashTable *ignore_recent;	/* hash table of UIDs to ignore as recent when updating folder */
+	gboolean check_folder;		/* persistent property */
 };
 
 #ifdef ENABLE_THREADS
 #define CAMEL_IMAP_FOLDER_LOCK(f, l) \
-	(g_static_mutex_lock(&((CamelImapFolder *)f)->priv->l))
+	(g_static_mutex_lock (&((CamelImapFolder *)f)->priv->l))
 #define CAMEL_IMAP_FOLDER_UNLOCK(f, l) \
-	(g_static_mutex_unlock(&((CamelImapFolder *)f)->priv->l))
+	(g_static_mutex_unlock (&((CamelImapFolder *)f)->priv->l))
 #define CAMEL_IMAP_FOLDER_REC_LOCK(f, l) \
-	(g_static_rec_mutex_lock(&((CamelImapFolder *)f)->priv->l))
+	(g_static_rec_mutex_lock (&((CamelImapFolder *)f)->priv->l))
 #define CAMEL_IMAP_FOLDER_REC_UNLOCK(f, l) \
-	(g_static_rec_mutex_unlock(&((CamelImapFolder *)f)->priv->l))
+	(g_static_rec_mutex_unlock (&((CamelImapFolder *)f)->priv->l))
 #else
 #define CAMEL_IMAP_FOLDER_LOCK(obj)
 #define CAMEL_IMAP_FOLDER_UNLOCK(obj)
