@@ -21,6 +21,10 @@
  * Author: Hans Petter Jansson <hpj@novell.com>
  */
 
+#ifdef GTK_DISABLE_DEPRECATED
+#undef GTK_DISABLE_DEPRECATED
+#endif
+
 #include <config.h>
 #include <string.h>
 #include <gdk/gdkkeysyms.h>
@@ -35,10 +39,6 @@
 #include "e-name-selector-dialog.h"
 #include "e-name-selector-entry.h"
 
-#define E_NAME_SELECTOR_DIALOG_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_NAME_SELECTOR_DIALOG, ENameSelectorDialogPrivate))
-
 typedef struct {
 	gchar        *name;
 
@@ -113,9 +113,15 @@ e_name_selector_dialog_populate_categories (ENameSelectorDialog *name_selector_d
 
 	/* Categories are already sorted. */
 	category_list = e_categories_get_list ();
-	for (iter = category_list; iter != NULL; iter = iter->next)
+	for (iter = category_list; iter != NULL; iter = iter->next) {
+		/* Only add user-visible categories. */
+		if (!e_categories_is_searchable (iter->data))
+			continue;
+
 		gtk_combo_box_text_append_text (
 			GTK_COMBO_BOX_TEXT (combo_box), iter->data);
+	}
+
 	g_list_free (category_list);
 
 	g_signal_connect_swapped (
@@ -159,8 +165,9 @@ e_name_selector_dialog_init (ENameSelectorDialog *name_selector_dialog)
 	GtkWidget *status_message;
 	GtkWidget *source_combo;
 
-	name_selector_dialog->priv =
-		E_NAME_SELECTOR_DIALOG_GET_PRIVATE (name_selector_dialog);
+	name_selector_dialog->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		name_selector_dialog, E_TYPE_NAME_SELECTOR_DIALOG,
+		ENameSelectorDialogPrivate);
 
 	name_selector_box = gtk_vbox_new (FALSE, 6);
 	gtk_widget_show (name_selector_box);
@@ -409,10 +416,6 @@ e_name_selector_dialog_init (ENameSelectorDialog *name_selector_dialog)
 static void
 e_name_selector_dialog_dispose (GObject *object)
 {
-	ENameSelectorDialogPrivate *priv;
-
-	priv = E_NAME_SELECTOR_DIALOG_GET_PRIVATE (object);
-
 	remove_books (E_NAME_SELECTOR_DIALOG (object));
 	shutdown_name_selector_model (E_NAME_SELECTOR_DIALOG (object));
 
@@ -425,7 +428,7 @@ e_name_selector_dialog_finalize (GObject *object)
 {
 	ENameSelectorDialogPrivate *priv;
 
-	priv = E_NAME_SELECTOR_DIALOG_GET_PRIVATE (object);
+	priv = E_NAME_SELECTOR_DIALOG (object)->priv;
 
 	g_slist_foreach (priv->user_query_fields, (GFunc)g_free, NULL);
 	g_slist_free (priv->user_query_fields);
@@ -696,7 +699,7 @@ add_section (ENameSelectorDialog *name_selector_dialog,
 	g_assert (pretty_name != NULL);
 	g_assert (E_IS_DESTINATION_STORE (destination_store));
 
-	priv = E_NAME_SELECTOR_DIALOG_GET_PRIVATE (name_selector_dialog);
+	priv = name_selector_dialog->priv;
 
 	memset (&section, 0, sizeof (Section));
 
@@ -948,7 +951,7 @@ source_changed (ENameSelectorDialog *name_selector_dialog,
 static void
 search_changed (ENameSelectorDialog *name_selector_dialog)
 {
-	ENameSelectorDialogPrivate *priv = E_NAME_SELECTOR_DIALOG_GET_PRIVATE (name_selector_dialog);
+	ENameSelectorDialogPrivate *priv = name_selector_dialog->priv;
 	EContactStore *contact_store;
 	EBookQuery    *book_query;
 	GtkWidget     *combo_box;
@@ -1273,7 +1276,6 @@ transfer_button_clicked (ENameSelectorDialog *name_selector_dialog, GtkButton *t
 static void
 setup_name_selector_model (ENameSelectorDialog *name_selector_dialog)
 {
-	EContactStore       *contact_store;
 	ETreeModelGenerator *contact_filter;
 	GList               *new_sections;
 	GList               *l;
@@ -1311,8 +1313,6 @@ setup_name_selector_model (ENameSelectorDialog *name_selector_dialog)
 
 	/* Get contact store and its filter wrapper */
 
-	contact_store  = e_name_selector_model_peek_contact_store  (
-		name_selector_dialog->priv->name_selector_model);
 	contact_filter = e_name_selector_model_peek_contact_filter (
 		name_selector_dialog->priv->name_selector_model);
 
